@@ -94,8 +94,12 @@ public:
 
     Status get_segments_size(std::vector<size_t>* segments_size);
 
+    void clear_inverted_index_cache() override;
+
     [[nodiscard]] virtual Status add_to_binlog() override;
 
+    void clear_cache() override;
+
 protected:
     BetaRowset(const TabletSchemaSPtr& schema, const std::string& tablet_path,
                const RowsetMetaSharedPtr& rowset_meta);
