@@ -84,6 +84,8 @@ public:
 
     RowsetReaderSharedPtr clone() override;
 
+    void set_topn_limit(size_t topn_limit) override { _topn_limit = topn_limit; }
+
 private:
     Status _init_iterator_once();
     Status _init_iterator();
@@ -122,6 +124,7 @@ private:
     StorageReadOptions _read_options;
 
     bool _empty = false;
+    size_t _topn_limit = 0;
 };
 
 } // namespace doris
