@@ -402,25 +402,8 @@ Status SegmentWriter::append_block_with_partial_content(const vectorized::Block*
     std::vector<RowsetSharedPtr> specified_rowsets;
     {
         std::shared_lock rlock(_tablet->get_header_lock());
-        // Under normal circumstances, `get_rowset_by_ids` does not need to consider the stale
-        // rowset, in other word, if a rowset id is not found in the normal rowset, we can ignore
-        // it. This is because even if we handle stale rowset here, we need to recalculate the
-        // new rowset generated by the corresponding compaction in the publish phase.
-        // However, for partial update, ignoring the stale rowset may cause some keys to not be
-        // found in the flush phase (lookup_row_key returns KEY_NOT_FOUND), and thus be mistaken
-        // as new keys in the flush phase, which will cause the load to fail in the following
-        // two cases:
-        // 1. when strict_mode is enabled, new keys are not allowed to be added.
-        // 2. Some columns that need to be filled are neither nullable nor have a default value,
-        //    in which case the value of the field cannot be filled as a new key, leading to a
-        //    failure of the load.
-        bool should_include_stale =
-                _opts.rowset_ctx->partial_update_info->is_strict_mode ||
-                !_opts.rowset_ctx->partial_update_info->can_insert_new_rows_in_partial_update;
-        specified_rowsets =
-                _tablet->get_rowset_by_ids(&_mow_context->rowset_ids, should_include_stale);
-        if (_opts.rowset_ctx->partial_update_info->is_strict_mode &&
-            specified_rowsets.size() != _mow_context->rowset_ids.size()) {
+        specified_rowsets = _mow_context->rowset_ptrs;
+        if (specified_rowsets.size() != _mow_context->rowset_ids.size()) {
             // Only when this is a strict mode partial update that missing rowsets here will lead to problems.
             // In other case, the missing rowsets will be calculated in later phases(commit phase/publish phase)
             LOG(WARNING) << fmt::format(
