@@ -790,11 +790,20 @@ Status SchemaChangeHandler::_do_process_alter_tablet_v2(const TAlterTabletReqV2&
         do {
             RowsetSharedPtr max_rowset;
             // get history data to be converted and it will check if there is hold in base tablet
-            if (!_get_versions_to_be_changed(base_tablet, &versions_to_be_changed, &max_rowset)) {
+            res = _get_versions_to_be_changed(base_tablet, &versions_to_be_changed, &max_rowset);
+            if (!res) {
                 LOG(WARNING) << "fail to get version to be changed. res=" << res;
                 break;
             }
 
+            DBUG_EXECUTE_IF("SchemaChangeJob.process_alter_tablet.alter_fail", {
+                res = Status::InternalError(
+                        "inject alter tablet failed. base_tablet={}, new_tablet={}",
+                        request.base_tablet_id, request.new_tablet_id);
+                LOG(WARNING) << "inject error. res=" << res;
+                break;
+            });
+
             // should check the max_version >= request.alter_version, if not the convert is useless
             if (max_rowset == nullptr || max_rowset->end_version() < request.alter_version) {
                 res = Status::InternalError(
