@@ -91,6 +91,10 @@ Status KafkaDataConsumer::init(std::shared_ptr<StreamLoadContext> ctx) {
     RETURN_IF_ERROR(set_conf("api.version.request", config::kafka_api_version_request));
     RETURN_IF_ERROR(set_conf("api.version.fallback.ms", "0"));
     RETURN_IF_ERROR(set_conf("broker.version.fallback", config::kafka_broker_version_fallback));
+    RETURN_IF_ERROR(set_conf("broker.address.ttl", "0"));
+    if (config::kafka_debug != "disable") {
+        RETURN_IF_ERROR(set_conf("debug", config::kafka_debug));
+    }
 
     for (auto& item : ctx->kafka_info->properties) {
         if (starts_with(item.second, "FILE:")) {
@@ -332,7 +336,7 @@ Status KafkaDataConsumer::get_partition_meta(std::vector<int32_t>* partition_ids
 // corresponding partition.
 // See librdkafka/rdkafkacpp.h##offsetsForTimes()
 Status KafkaDataConsumer::get_offsets_for_times(const std::vector<PIntegerPair>& times,
-                                                std::vector<PIntegerPair>* offsets) {
+                                                std::vector<PIntegerPair>* offsets, int timeout) {
     // create topic partition
     std::vector<RdKafka::TopicPartition*> topic_partitions;
     for (const auto& entry : times) {
@@ -347,8 +351,8 @@ Status KafkaDataConsumer::get_offsets_for_times(const std::vector<PIntegerPair>&
     }};
 
     // get offsets for times
-    RdKafka::ErrorCode err = _k_consumer->offsetsForTimes(topic_partitions, 5000);
-    if (err != RdKafka::ERR_NO_ERROR) {
+    RdKafka::ErrorCode err = _k_consumer->offsetsForTimes(topic_partitions, timeout);
+    if (UNLIKELY(err != RdKafka::ERR_NO_ERROR)) {
         std::stringstream ss;
         ss << "failed to get offsets for times: " << RdKafka::err2str(err);
         LOG(WARNING) << ss.str();
@@ -367,13 +371,21 @@ Status KafkaDataConsumer::get_offsets_for_times(const std::vector<PIntegerPair>&
 
 // get latest offsets for given partitions
 Status KafkaDataConsumer::get_latest_offsets_for_partitions(
-        const std::vector<int32_t>& partition_ids, std::vector<PIntegerPair>* offsets) {
+        const std::vector<int32_t>& partition_ids, std::vector<PIntegerPair>* offsets,
+        int timeout) {
+    MonotonicStopWatch watch;
+    watch.start();
     for (int32_t partition_id : partition_ids) {
         int64_t low = 0;
         int64_t high = 0;
+        auto timeout_ms = timeout - static_cast<int>(watch.elapsed_time() / 1000 / 1000);
+        if (UNLIKELY(timeout_ms <= 0)) {
+            return Status::InternalError("get kafka latest offsets for partitions timeout");
+        }
+
         RdKafka::ErrorCode err =
-                _k_consumer->query_watermark_offsets(_topic, partition_id, &low, &high, 5000);
-        if (err != RdKafka::ERR_NO_ERROR) {
+                _k_consumer->query_watermark_offsets(_topic, partition_id, &low, &high, timeout_ms);
+        if (UNLIKELY(err != RdKafka::ERR_NO_ERROR)) {
             std::stringstream ss;
             ss << "failed to get latest offset for partition: " << partition_id
                << ", err: " << RdKafka::err2str(err);
