@@ -128,7 +128,8 @@ Status RoutineLoadTaskExecutor::get_kafka_partition_meta(const PKafkaMetaProxyRe
 }
 
 Status RoutineLoadTaskExecutor::get_kafka_partition_offsets_for_times(
-        const PKafkaMetaProxyRequest& request, std::vector<PIntegerPair>* partition_offsets) {
+        const PKafkaMetaProxyRequest& request, std::vector<PIntegerPair>* partition_offsets,
+        int timeout) {
     CHECK(request.has_kafka_info());
 
     // This context is meaningless, just for unifing the interface
@@ -140,7 +141,7 @@ Status RoutineLoadTaskExecutor::get_kafka_partition_offsets_for_times(
 
     Status st = std::static_pointer_cast<KafkaDataConsumer>(consumer)->get_offsets_for_times(
             std::vector<PIntegerPair>(request.offset_times().begin(), request.offset_times().end()),
-            partition_offsets);
+            partition_offsets, timeout);
     if (st.ok()) {
         _data_consumer_pool.return_consumer(consumer);
     }
@@ -148,7 +149,8 @@ Status RoutineLoadTaskExecutor::get_kafka_partition_offsets_for_times(
 }
 
 Status RoutineLoadTaskExecutor::get_kafka_latest_offsets_for_partitions(
-        const PKafkaMetaProxyRequest& request, std::vector<PIntegerPair>* partition_offsets) {
+        const PKafkaMetaProxyRequest& request, std::vector<PIntegerPair>* partition_offsets,
+        int timeout) {
     CHECK(request.has_kafka_info());
 
     // This context is meaningless, just for unifing the interface
@@ -163,7 +165,7 @@ Status RoutineLoadTaskExecutor::get_kafka_latest_offsets_for_partitions(
                     ->get_latest_offsets_for_partitions(
                             std::vector<int32_t>(request.partition_id_for_latest_offsets().begin(),
                                                  request.partition_id_for_latest_offsets().end()),
-                            partition_offsets);
+                            partition_offsets, timeout);
     if (st.ok()) {
         _data_consumer_pool.return_consumer(consumer);
     }
