@@ -20,12 +20,18 @@
 
 #include "vec/columns/column_string.h"
 
+#include <algorithm>
+#include <boost/iterator/iterator_facade.hpp>
+#include <ostream>
+
+#include "util/simd/bits.h"
 #include "vec/columns/columns_common.h"
 #include "vec/common/arena.h"
 #include "vec/common/assert_cast.h"
 #include "vec/common/memcmp_small.h"
 #include "vec/common/unaligned.h"
 #include "vec/core/sort_block.h"
+#include "vec/data_types/data_type.h"
 
 namespace doris::vectorized {
 
@@ -124,6 +130,9 @@ void ColumnString::insert_indices_from(const IColumn& src, const int* indices_be
         if (*x == -1) {
             ColumnString::insert_default();
         } else {
+            if (x + IColumn::PREFETCH_STEP < indices_end && (-1 != x[IColumn::PREFETCH_STEP])) {
+                ColumnString::prefetch(src, *(x + IColumn::PREFETCH_STEP));
+            }
             ColumnString::insert_from(src, *x);
         }
     }
@@ -164,6 +173,16 @@ ColumnPtr ColumnString::filter(const Filter& filt, ssize_t result_size_hint) con
     return res;
 }
 
+size_t ColumnString::filter(const Filter& filter) {
+    CHECK_EQ(filter.size(), offsets.size());
+    if (offsets.size() == 0) {
+        resize(0);
+        return 0;
+    }
+
+    return filter_arrays_impl<UInt8, Offset>(chars, offsets, filter);
+}
+
 ColumnPtr ColumnString::permute(const Permutation& perm, size_t limit) const {
     size_t size = offsets.size();
 
@@ -383,9 +402,7 @@ void ColumnString::get_permutation(bool reverse, size_t limit, int /*nan_directi
 
 ColumnPtr ColumnString::replicate(const Offsets& replicate_offsets) const {
     size_t col_size = size();
-    if (col_size != replicate_offsets.size()) {
-        LOG(FATAL) << "Size of offsets doesn't match size of column.";
-    }
+    column_match_offsets_size(col_size, replicate_offsets.size());
 
     auto res = ColumnString::create();
 
@@ -423,39 +440,29 @@ ColumnPtr ColumnString::replicate(const Offsets& replicate_offsets) const {
     return res;
 }
 
-void ColumnString::replicate(const uint32_t* counts, size_t target_size, IColumn& column,
-                             size_t begin, int count_sz) const {
-    size_t col_size = count_sz < 0 ? size() : count_sz;
-    if (0 == col_size) {
-        return;
-    }
-
+void ColumnString::replicate(const uint32_t* indexs, size_t target_size, IColumn& column) const {
     auto& res = reinterpret_cast<ColumnString&>(column);
 
     Chars& res_chars = res.chars;
     Offsets& res_offsets = res.offsets;
-    res_chars.reserve(chars.size() / col_size * target_size);
-    res_offsets.reserve(target_size);
 
-    size_t base = begin > 0 ? offsets[begin - 1] : 0;
-    Offset prev_string_offset = 0 + base;
-    Offset current_new_offset = 0;
+    size_t byte_size = 0;
+    res_offsets.resize(target_size);
+    for (size_t i = 0; i < target_size; ++i) {
+        long row_idx = indexs[i];
+        auto str_size = offsets[row_idx] - offsets[row_idx - 1];
+        res_offsets[i] = res_offsets[i - 1] + str_size;
+        byte_size += str_size;
+    }
 
-    size_t end = begin + col_size;
-    for (size_t i = begin; i < end; ++i) {
-        size_t size_to_replicate = counts[i];
-        size_t string_size = offsets[i] - prev_string_offset;
-
-        for (size_t j = 0; j < size_to_replicate; ++j) {
-            current_new_offset += string_size;
-            res_offsets.push_back(current_new_offset);
-
-            res_chars.resize(res_chars.size() + string_size);
-            memcpy_small_allow_read_write_overflow15(&res_chars[res_chars.size() - string_size],
-                                                     &chars[prev_string_offset], string_size);
-        }
-
-        prev_string_offset = offsets[i];
+    res_chars.resize(byte_size);
+    auto* __restrict dest = res.chars.data();
+    auto* __restrict src = chars.data();
+    for (size_t i = 0; i < target_size; ++i) {
+        long row_idx = indexs[i];
+        auto str_size = offsets[row_idx] - offsets[row_idx - 1];
+        memcpy_small_allow_read_write_overflow15(dest + res_offsets[i - 1],
+                                                 src + offsets[row_idx - 1], str_size);
     }
 
     check_chars_length(res_chars.size(), res_offsets.size());
@@ -537,4 +544,8 @@ void ColumnString::compare_internal(size_t rhs_row_id, const IColumn& rhs, int n
     }
 }
 
+ColumnPtr ColumnString::index(const IColumn& indexes, size_t limit) const {
+    return select_index_impl(*this, indexes, limit);
+}
+
 } // namespace doris::vectorized
