@@ -64,8 +64,9 @@ public:
         __builtin_unreachable();
     }
 
-    DataTypeDecimalSerDe(int scale_, int precision_)
-            : scale(scale_),
+    DataTypeDecimalSerDe(int scale_, int precision_, int nesting_level = 1)
+            : DataTypeSerDe(nesting_level),
+              scale(scale_),
               precision(precision_),
               scale_multiplier(decimal_scale_multiplier<typename T::NativeType>(scale)) {}
 
@@ -76,12 +77,11 @@ public:
                                   BufferWritable& bw, FormatOptions& options) const override;
 
     Status deserialize_one_cell_from_json(IColumn& column, Slice& slice,
-                                          const FormatOptions& options,
-                                          int nesting_level = 1) const override;
+                                          const FormatOptions& options) const override;
 
     Status deserialize_column_from_json_vector(IColumn& column, std::vector<Slice>& slices,
-                                               int* num_deserialized, const FormatOptions& options,
-                                               int nesting_level = 1) const override;
+                                               int* num_deserialized,
+                                               const FormatOptions& options) const override;
 
     Status write_column_to_pb(const IColumn& column, PValues& result, int start,
                               int end) const override;
