@@ -586,5 +586,10 @@ public class CastExpr extends Expr {
     public boolean isNotFold() {
         return this.notFold;
     }
+
+    @Override
+    protected void compactForLiteral(Type type) {
+        // do nothing
+    }
 }
 
