@@ -28,6 +28,8 @@ import org.apache.doris.qe.ConnectContext;
 import java.util.Map;
 
 public class CreateRepositoryStmt extends DdlStmt {
+    public static String PROP_DELETE_IF_EXISTS = "delete_if_exists";
+
     private boolean isReadOnly;
     private String name;
     private StorageBackend storage;
@@ -47,11 +49,11 @@ public class CreateRepositoryStmt extends DdlStmt {
     }
 
     public String getBrokerName() {
-        return storage.getStorageName();
+        return storage.getStorageDesc().getName();
     }
 
     public StorageBackend.StorageType getStorageType() {
-        return storage.getStorageType();
+        return storage.getStorageDesc().getStorageType();
     }
 
     public String getLocation() {
@@ -59,7 +61,7 @@ public class CreateRepositoryStmt extends DdlStmt {
     }
 
     public Map<String, String> getProperties() {
-        return storage.getProperties();
+        return storage.getStorageDesc().getProperties();
     }
 
     @Override
@@ -67,10 +69,20 @@ public class CreateRepositoryStmt extends DdlStmt {
         super.analyze(analyzer);
         storage.analyze(analyzer);
         // check auth
-        if (!Env.getCurrentEnv().getAuth().checkGlobalPriv(ConnectContext.get(), PrivPredicate.ADMIN)) {
+        if (!Env.getCurrentEnv().getAccessManager().checkGlobalPriv(ConnectContext.get(), PrivPredicate.ADMIN)) {
             ErrorReport.reportAnalysisException(ErrorCode.ERR_SPECIFIC_ACCESS_DENIED_ERROR, "ADMIN");
         }
         FeNameFormat.checkCommonName("repository", name);
+
+        // check delete_if_exists, this property will be used by Repository.initRepository.
+        Map<String, String> properties = getProperties();
+        String deleteIfExistsStr = properties.get(PROP_DELETE_IF_EXISTS);
+        if (deleteIfExistsStr != null) {
+            if (!deleteIfExistsStr.equalsIgnoreCase("true") && !deleteIfExistsStr.equalsIgnoreCase("false")) {
+                ErrorReport.reportAnalysisException(ErrorCode.ERR_COMMON_ERROR,
+                        "'" + PROP_DELETE_IF_EXISTS + "' in properties, you should set it false or true");
+            }
+        }
     }
 
     @Override
