@@ -48,6 +48,7 @@ import java.io.IOException;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.stream.Collectors;
 
 /**
  * Resource manager is responsible for managing external resources used by Doris.
@@ -94,6 +95,7 @@ public class ResourceMgr implements Writable {
     }
 
     public void replayCreateResource(Resource resource) {
+        resource.applyDefaultProperties();
         nameToResource.put(resource.getName(), resource);
     }
 
@@ -167,6 +169,11 @@ public class ResourceMgr implements Writable {
         return nameToResource.size();
     }
 
+    public List<Resource> getResource(ResourceType type) {
+        return nameToResource.values().stream().filter(resource -> resource.getType() == type)
+                .collect(Collectors.toList());
+    }
+
     public List<List<Comparable>> getResourcesInfo(String name, boolean accurateMatch, Set<String> typeSets) {
         List<List<String>> targetRows = procNode.fetchResult().getRows();
         List<List<Comparable>> returnRows = Lists.newArrayList();
@@ -228,7 +235,7 @@ public class ResourceMgr implements Writable {
             for (Map.Entry<String, Resource> entry : nameToResource.entrySet()) {
                 Resource resource = entry.getValue();
                 // check resource privs
-                if (!Env.getCurrentEnv().getAuth().checkResourcePriv(ConnectContext.get(), resource.getName(),
+                if (!Env.getCurrentEnv().getAccessManager().checkResourcePriv(ConnectContext.get(), resource.getName(),
                                                                              PrivPredicate.SHOW_RESOURCES)) {
                     continue;
                 }
