@@ -50,7 +50,6 @@ import org.apache.logging.log4j.Logger;
 import java.io.DataInput;
 import java.io.DataOutput;
 import java.io.IOException;
-import java.text.SimpleDateFormat;
 import java.util.ArrayList;
 import java.util.Comparator;
 import java.util.Iterator;
@@ -143,8 +142,7 @@ public class StreamLoadRecordMgr extends MasterDaemon {
         Map<String, StreamLoadRecord> labelToStreamLoadRecord = dbIdToLabelToStreamLoadRecord.get(dbId);
         if (!labelToStreamLoadRecord.containsKey(label)) {
             labelToStreamLoadRecord.put(label, streamLoadRecord);
-        }
-        else if (labelToStreamLoadRecord.get(label).getFinishTime().compareTo(streamLoadRecord.getFinishTime()) < 0) {
+        } else if (labelToStreamLoadRecord.get(label).getFinishTime().compareTo(streamLoadRecord.getFinishTime()) < 0) {
             labelToStreamLoadRecord.put(label, streamLoadRecord);
         }
         writeUnlock();
@@ -251,9 +249,9 @@ public class StreamLoadRecordMgr extends MasterDaemon {
                 for (Map.Entry<String, TStreamLoadRecord> entry : streamLoadRecordBatch.entrySet()) {
                     TStreamLoadRecord streamLoadItem = entry.getValue();
                     String startTime = TimeUtils.longToTimeString(streamLoadItem.getStartTime(),
-                            new SimpleDateFormat("yyyy-MM-dd HH:mm:ss.SSS"));
+                            TimeUtils.DATETIME_MS_FORMAT);
                     String finishTime = TimeUtils.longToTimeString(streamLoadItem.getFinishTime(),
-                            new SimpleDateFormat("yyyy-MM-dd HH:mm:ss.SSS"));
+                            TimeUtils.DATETIME_MS_FORMAT);
                     if (LOG.isDebugEnabled()) {
                         LOG.debug("receive stream load record info from backend: {}."
                                         + " label: {}, db: {}, tbl: {}, user: {}, user_ip: {},"
@@ -290,13 +288,14 @@ public class StreamLoadRecordMgr extends MasterDaemon {
                     }
                     StreamLoadRecord streamLoadRecord =
                             new StreamLoadRecord(streamLoadItem.getLabel(), streamLoadItem.getDb(),
-                                    streamLoadItem.getTbl(), streamLoadItem.getUser(), streamLoadItem.getUserIp(),
+                                    streamLoadItem.getTbl(), streamLoadItem.getUserIp(),
                                     streamLoadItem.getStatus(), streamLoadItem.getMessage(), streamLoadItem.getUrl(),
                                     String.valueOf(streamLoadItem.getTotalRows()),
                                     String.valueOf(streamLoadItem.getLoadedRows()),
                                     String.valueOf(streamLoadItem.getFilteredRows()),
                                     String.valueOf(streamLoadItem.getUnselectedRows()),
-                                    String.valueOf(streamLoadItem.getLoadBytes()), startTime, finishTime);
+                                    String.valueOf(streamLoadItem.getLoadBytes()),
+                                    startTime, finishTime, streamLoadItem.getUser(), streamLoadItem.getComment());
 
                     String cluster = streamLoadItem.getCluster();
                     if (Strings.isNullOrEmpty(cluster)) {
