@@ -64,6 +64,7 @@ import org.apache.doris.qe.ConnectContext;
 
 import com.google.common.base.Preconditions;
 import com.google.common.collect.ImmutableList;
+import com.google.common.collect.Lists;
 import com.google.common.collect.Sets;
 import org.apache.commons.collections.CollectionUtils;
 
@@ -187,7 +188,7 @@ public class BindRelation extends OneAnalysisRuleFactory {
         List<Long> tabletIds = unboundRelation.getTabletIds();
         if (!CollectionUtils.isEmpty(partIds)) {
             scan = new LogicalOlapScan(unboundRelation.getRelationId(),
-                    (OlapTable) table, ImmutableList.of(tableQualifier.get(1)), partIds,
+                    (OlapTable) table, tableQualifier, partIds,
                     tabletIds, unboundRelation.getHints(), unboundRelation.getTableSample());
         } else {
             Optional<String> indexName = unboundRelation.getIndexName();
@@ -204,11 +205,11 @@ public class BindRelation extends OneAnalysisRuleFactory {
                         : PreAggStatus.off("For direct index scan.");
 
                 scan = new LogicalOlapScan(unboundRelation.getRelationId(),
-                    (OlapTable) table, ImmutableList.of(tableQualifier.get(1)), tabletIds, indexId,
+                    (OlapTable) table, tableQualifier, tabletIds, indexId,
                     preAggStatus, unboundRelation.getHints(), unboundRelation.getTableSample());
             } else {
                 scan = new LogicalOlapScan(unboundRelation.getRelationId(),
-                    (OlapTable) table, ImmutableList.of(tableQualifier.get(1)), tabletIds, unboundRelation.getHints(),
+                    (OlapTable) table, tableQualifier, tabletIds, unboundRelation.getHints(),
                     unboundRelation.getTableSample());
             }
         }
@@ -246,9 +247,11 @@ public class BindRelation extends OneAnalysisRuleFactory {
 
     private LogicalPlan doGetLogicalPlan(TableIf table, UnboundRelation unboundRelation, List<String> tableQualifier,
                                        CascadesContext cascadesContext) {
+        List<String> qualifierWithoutTableName = Lists.newArrayList();
+        qualifierWithoutTableName.addAll(tableQualifier.subList(0, tableQualifier.size() - 1));
         switch (table.getType()) {
             case OLAP:
-                return makeOlapScan(table, unboundRelation, tableQualifier);
+                return makeOlapScan(table, unboundRelation, qualifierWithoutTableName);
             case VIEW:
                 Plan viewPlan = parseAndAnalyzeView(((View) table).getDdlSql(), cascadesContext);
                 return new LogicalSubQueryAlias<>(tableQualifier, viewPlan);
@@ -259,22 +262,23 @@ public class BindRelation extends OneAnalysisRuleFactory {
                     Plan hiveViewPlan = parseAndAnalyzeHiveView(hiveCatalog, ddlSql, cascadesContext);
                     return new LogicalSubQueryAlias<>(tableQualifier, hiveViewPlan);
                 }
-                return new LogicalFileScan(unboundRelation.getRelationId(), (HMSExternalTable) table, tableQualifier,
-                    unboundRelation.getTableSample());
+                return new LogicalFileScan(unboundRelation.getRelationId(), (HMSExternalTable) table,
+                        qualifierWithoutTableName, unboundRelation.getTableSample());
             case ICEBERG_EXTERNAL_TABLE:
             case PAIMON_EXTERNAL_TABLE:
             case MAX_COMPUTE_EXTERNAL_TABLE:
-                return new LogicalFileScan(unboundRelation.getRelationId(), (ExternalTable) table, tableQualifier,
-                    unboundRelation.getTableSample());
+                return new LogicalFileScan(unboundRelation.getRelationId(), (ExternalTable) table,
+                        qualifierWithoutTableName, unboundRelation.getTableSample());
             case SCHEMA:
-                return new LogicalSchemaScan(unboundRelation.getRelationId(), table, tableQualifier);
+                return new LogicalSchemaScan(unboundRelation.getRelationId(), table, qualifierWithoutTableName);
             case JDBC_EXTERNAL_TABLE:
             case JDBC:
-                return new LogicalJdbcScan(unboundRelation.getRelationId(), table, tableQualifier);
+                return new LogicalJdbcScan(unboundRelation.getRelationId(), table, qualifierWithoutTableName);
             case ODBC:
-                return new LogicalOdbcScan(unboundRelation.getRelationId(), table, tableQualifier);
+                return new LogicalOdbcScan(unboundRelation.getRelationId(), table, qualifierWithoutTableName);
             case ES_EXTERNAL_TABLE:
-                return new LogicalEsScan(unboundRelation.getRelationId(), (EsExternalTable) table, tableQualifier);
+                return new LogicalEsScan(unboundRelation.getRelationId(), (EsExternalTable) table,
+                        qualifierWithoutTableName);
             default:
                 throw new AnalysisException("Unsupported tableType:" + table.getType());
         }
