@@ -182,6 +182,9 @@ public interface NormalizeToSlot {
                 }
                 newChildren.add(newChild);
             }
+            if (windowExpression.getWindowFrame().isPresent()) {
+                newChildren.add(windowExpression.getWindowFrame().get());
+            }
             return hasNewChildren ? windowExpression.withChildren(newChildren) : windowExpression;
         }
     }
