@@ -20,29 +20,35 @@ package org.apache.doris.system;
 import org.apache.doris.common.io.Writable;
 import org.apache.doris.resource.Tag;
 
+import com.google.gson.annotations.SerializedName;
+
 import java.io.DataInput;
-import java.io.DataOutput;
 import java.io.IOException;
 
 /**
  * Backend heartbeat response contains Backend's be port, http port and brpc port
  */
 public class BackendHbResponse extends HeartbeatResponse implements Writable {
+    @SerializedName(value = "beId")
     private long beId;
+    @SerializedName(value = "bePort")
     private int bePort;
+    @SerializedName(value = "httpPort")
     private int httpPort;
+    @SerializedName(value = "brpcPort")
     private int brpcPort;
+    @SerializedName(value = "nodeRole")
+    private String nodeRole = Tag.VALUE_MIX;
     private long beStartTime;
     private String host;
     private String version = "";
-    private String nodeRole = Tag.VALUE_MIX;
 
     public BackendHbResponse() {
         super(HeartbeatResponse.Type.BACKEND);
     }
 
-    public BackendHbResponse(long beId, int bePort, int httpPort, int brpcPort,
-            long hbTime, long beStartTime, String version, String nodeRole) {
+    public BackendHbResponse(long beId, int bePort, int httpPort, int brpcPort, long hbTime, long beStartTime,
+            String version, String nodeRole) {
         super(HeartbeatResponse.Type.BACKEND);
         this.beId = beId;
         this.status = HbStatus.OK;
@@ -98,23 +104,8 @@ public class BackendHbResponse extends HeartbeatResponse implements Writable {
         return nodeRole;
     }
 
-    public static BackendHbResponse read(DataInput in) throws IOException {
-        BackendHbResponse result = new BackendHbResponse();
-        result.readFields(in);
-        return result;
-    }
-
     @Override
-    public void write(DataOutput out) throws IOException {
-        super.write(out);
-        out.writeLong(beId);
-        out.writeInt(bePort);
-        out.writeInt(httpPort);
-        out.writeInt(brpcPort);
-    }
-
-    @Override
-    public void readFields(DataInput in) throws IOException {
+    protected void readFields(DataInput in) throws IOException {
         super.readFields(in);
         beId = in.readLong();
         bePort = in.readInt();
