@@ -28,6 +28,7 @@ import org.apache.doris.nereids.trees.expressions.EqualTo;
 import org.apache.doris.nereids.trees.expressions.Expression;
 import org.apache.doris.nereids.trees.expressions.Slot;
 import org.apache.doris.nereids.trees.expressions.SlotReference;
+import org.apache.doris.nereids.trees.plans.JoinHint;
 import org.apache.doris.nereids.trees.plans.JoinType;
 import org.apache.doris.nereids.trees.plans.Plan;
 import org.apache.doris.nereids.trees.plans.logical.LogicalJoin;
@@ -51,6 +52,7 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Optional;
+import java.util.Random;
 import java.util.Set;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
@@ -116,7 +118,7 @@ public class HyperGraphBuilder {
     public Plan buildJoinPlan() {
         assert plans.size() == 1 : "there are cross join";
         Plan plan = plans.values().iterator().next();
-        return buildPlanWithJoinType(plan, new BitSet());
+        return buildPlanWithJoinType(plan, new BitSet(), false);
     }
 
     public Plan randomBuildPlanWith(int tableNum, int edgeNum) {
@@ -129,6 +131,13 @@ public class HyperGraphBuilder {
         return this.build();
     }
 
+    public Plan buildJoinPlanWithJoinHint(int tableNum, int edgeNum) {
+        randomBuildInit(tableNum, edgeNum);
+        assert plans.size() == 1 : "there are cross join";
+        Plan plan = plans.values().iterator().next();
+        return buildPlanWithJoinType(plan, new BitSet(), true);
+    }
+
     private void randomBuildInit(int tableNum, int edgeNum) {
         Preconditions.checkArgument(edgeNum >= tableNum - 1,
                 String.format("We can't build a connected graph with %d tables %d edges", tableNum, edgeNum));
@@ -243,7 +252,7 @@ public class HyperGraphBuilder {
         return this;
     }
 
-    private Plan buildPlanWithJoinType(Plan plan, BitSet requireTable) {
+    private Plan buildPlanWithJoinType(Plan plan, BitSet requireTable, boolean withJoinHint) {
         if (!(plan instanceof LogicalJoin)) {
             return plan;
         }
@@ -270,11 +279,20 @@ public class HyperGraphBuilder {
             }
         }
 
-        Plan left = buildPlanWithJoinType(join.left(), requireTable);
-        Plan right = buildPlanWithJoinType(join.right(), requireTable);
+        Plan left = buildPlanWithJoinType(join.left(), requireTable, withJoinHint);
+        Plan right = buildPlanWithJoinType(join.right(), requireTable, withJoinHint);
         Set<Slot> outputs = Stream.concat(left.getOutput().stream(), right.getOutput().stream())
                 .collect(Collectors.toSet());
         assert outputs.containsAll(requireSlots);
+        if (withJoinHint) {
+            JoinHint[] values = JoinHint.values();
+            Random random = new Random();
+            int randomIndex = random.nextInt(values.length);
+            JoinHint hint = values[randomIndex];
+            Plan hintJoin = ((LogicalJoin) join.withChildren(left, right)).withJoinType(joinType);
+            ((LogicalJoin) hintJoin).setHint(hint);
+            return hintJoin;
+        }
         return ((LogicalJoin) join.withChildren(left, right)).withJoinType(joinType);
     }
 
@@ -526,6 +544,8 @@ public class HyperGraphBuilder {
                             matchPair.stream().map(p -> Pair.of(p.second, p.first)).collect(Collectors.toList()));
                 case NULL_AWARE_LEFT_ANTI_JOIN:
                     return calLNAAJ(left, right, matchPair);
+                case CROSS_JOIN:
+                    return calFOJ(left, right, matchPair);
                 default:
                     assert false;
             }
